
# Overview

Pressio is an open-source computational framework aimed at enabling
leading-edge projection-based reduced-order models (pROMs) capabilties
for dynamical systems in science and engineering.

# Userguide and documentation
This is the repository for the Python bindings.
You can find the full user-guide [here](https://pressio.github.io/pressio4py/html/index.html).

The full Pressio project site can be found [here](https://pressio.github.io).

# License and Citation
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)

The full license is available [here](https://pressio.github.io/various/license/).

We are working on publishing this: you can find our arXiv preprint at: https://arxiv.org/abs/2003.07798.

# Questions?
Find us on Slack: https://pressioteam.slack.com or open an issue on [github](https://github.com/Pressio/pressio4py).
